@@ -10,8 +10,8 @@ See the cf-plot home page http://ajheaps.github.io/cf-plot for a gallery of plot
 '''
 
 __author__ = 'Andy Heaps - andy.heaps@ncas.ac.uk'
-__date__ = '27th April 2020'
-__version__ = '3.0.19'
+__date__ = '6th July 2020'
+__version__ = '3.0.25'
 
 from .cfplot import *
 
